@@ -1,3 +1,3 @@
 from perdido.utils.webservices import WebService
-from perdido.utils.xml import *
+from perdido.utils.utils import *
 from perdido.utils.map import *
\ No newline at end of file
